import { FontAwesome } from '@gibme/fontawesome';
export declare abstract class Overlay {
    private static instances;
    /**
     * Returns if the overlay is currently open for the specified element
     *
     * @param parent
     */
    static isOpen(parent?: JQuery | string): boolean;
    /**
     * Handles our actions against the parent
     *
     * @param parent
     * @param action
     * @param options
     */
    static handle(parent: JQuery, action: Overlay.Action, options?: Overlay.OptionsLike): JQuery;
    /**
     * Font size helper for a few sizes
     *
     * @param overlay
     * @param resizeFactor
     * @protected
     */
    private static calculate_size;
    /**
     * Shows the overlay
     *
     * @param parent
     * @param overlayId
     * @param options
     * @protected
     */
    private static show;
    /**
     * Hides the overlay
     *
     * @param parent
     * @param overlayId
     * @param options
     * @protected
     */
    private static hide;
    /**
     * Updates the progress bar in the overlay
     *
     * @param parent
     * @param overlayId
     * @param options
     * @protected
     */
    private static progress;
    /**
     * Resizes the text element
     *
     * @param parent
     * @param overlayId
     * @param options
     * @private
     */
    private static resize_text;
    /**
     * Resizes the icon element
     *
     * @param parent
     * @param overlayId
     * @param options
     * @private
     */
    private static resize_icon;
    /**
     * Resizes the image element
     *
     * @param parent
     * @param overlayId
     * @param options
     * @private
     */
    private static resize_image;
    /**
     * Resizes the progress element
     *
     * @param parent
     * @param overlayId
     * @param options
     * @private
     */
    private static resize_progress;
    /**
     * Performs a resize of elements in the overlay
     *
     * @param parent
     * @param overlayId
     * @param options
     * @protected
     */
    private static resize;
    /**
     * Performs a resize if the property is set to autoreset for that object
     *
     * @param parent
     * @param overlayId
     * @param options
     * @protected
     */
    private static auto_resize;
    /**
     * Updates the text in the overlay
     *
     * @param parent
     * @param overlayId
     * @param options
     * @protected
     */
    private static text;
    /**
     * Updates the image in the overlay
     *
     * @param parent
     * @param overlayId
     * @param options
     * @private
     */
    private static image;
    /**
     * Updates the icon in the overlay
     *
     * @param parent
     * @param overlayId
     * @param options
     * @protected
     */
    private static icon;
    /**
     * Adjusts the order to fit within the bootstrap range of pre-defined orders
     *
     * @param default_value
     * @param order
     * @private
     */
    private static adjust_order;
    /**
     * Merges "new" options with cached options and updates the cache
     *
     * @param parent_path
     * @param overlayId
     * @param new_options
     * @private
     */
    private static merge_options;
    /**
     * Performs a deep merge of the options supplied with the default options
     * @param target
     * @param source
     * @private
     */
    private static _merge_options;
    /**
     * Gets, or sets if undefined, the element's Id attribute
     *
     * @param element
     * @private
     */
    private static get_or_set_element_id;
}
export declare namespace Overlay {
    type Action = 'show' | 'hide' | 'progress' | 'resize' | 'text' | 'icon' | 'image';
    type AutoResize = {
        autoResize: boolean;
        resizeFactor: number;
    };
    type HasOrder = {
        order: number;
    };
    type BaseOptions = {
        className: string;
        color: FontAwesome.Color;
    };
    type CanHide = {
        hide: boolean;
    };
    namespace Background {
        type Options = BaseOptions;
    }
    namespace Image {
        type Options = Partial<BaseOptions> & Partial<AutoResize> & Partial<CanHide> & Partial<HasOrder> & {
            source: string;
            animation?: FontAwesome.Animation;
            rotation?: FontAwesome.Rotation;
            width?: number;
            height?: number;
        };
    }
    namespace Icon {
        type Options = Partial<FontAwesome.Icon.Options> & Partial<AutoResize> & Partial<CanHide> & HasOrder & {
            name: string | string[];
        };
    }
    namespace Text {
        type Options = Partial<BaseOptions> & Partial<AutoResize> & Partial<HasOrder> & {
            message: string | JQuery;
        };
    }
    namespace Progress {
        type Options = Partial<BaseOptions> & Partial<AutoResize> & Partial<HasOrder> & {
            value: number;
            min: number;
            max: number;
            animated: boolean;
        };
    }
    type Options = {
        background: Partial<Background.Options>;
        icon: Partial<Icon.Options>;
        image: Partial<Image.Options>;
        text: Partial<Text.Options>;
        progress: Partial<Progress.Options>;
        resizeInterval: number;
        fade: {
            in?: number | boolean;
            out?: number | boolean;
        };
        zIndex: number;
        timeout?: number;
    };
    type OptionsLike = Partial<Options> | Partial<Icon.Options> | JQuery | string | number;
    const DefaultOptions: Readonly<Overlay.Options>;
}
export default Overlay;
